bayespy.nodes.VaryingGaussianMarkovChain.get_parameters
=======================================================

.. currentmodule:: bayespy.nodes

.. automethod:: VaryingGaussianMarkovChain.get_parameters